@@ -84,12 +84,13 @@ class MoleculeSet:
                 Spectral Embedding ('spectral_embedding')
 
     """
+
     def __init__(
         self,
-        molecule_database_src,
-        molecule_database_src_type,
-        is_verbose,
-        similarity_measure,
+        molecule_database_src: str,
+        molecule_database_src_type: str,
+        is_verbose: bool,
+        similarity_measure: str,
         n_threads=1,
         fingerprint_type=None,
         fingerprint_params=None,
@@ -107,11 +108,11 @@ class MoleculeSet:
         self.is_verbose = is_verbose
         self.molecule_database = None
         self.descriptor = Descriptor()
-        self.molecule_database, features = self._get_molecule_database(
+        self.molecule_database, descriptors = self._get_molecule_database(
             molecule_database_src, molecule_database_src_type
         )
-        if features is not None:
-            self._set_descriptor(arbitrary_descriptor_vals=features)
+        if descriptors is not None:
+            self._set_descriptor(arbitrary_descriptor_vals=descriptors)
         if 0.0 < sampling_ratio < 1.0:
             if self.is_verbose:
                 print(f"Using {int(sampling_ratio * 100)}% of the database...")
@@ -120,7 +121,10 @@ class MoleculeSet:
                 random_state=sampling_random_state
             )
         if fingerprint_type is not None:
-            # overrides if descriptor set in self._set_molecule_database
+            if descriptors is not None and is_verbose:
+                print('Descriptor and fingerprint specified.'
+                      'Descriptors imported from database source will '
+                      'be overwritten by fingerprint.')
             self._set_descriptor(
                 fingerprint_type=fingerprint_type,
                 fingerprint_params=fingerprint_params
@@ -169,7 +173,7 @@ class MoleculeSet:
             RDLogger.DisableLog('rdApp.*')
 
         molecule_database = []
-        features = None
+        descriptors = None
         if molecule_database_src_type.lower() in ["folder", "directory"]:
             if self.is_verbose:
                 print(f"Searching for *.pdb files in {molecule_database_src}")
@@ -218,24 +222,24 @@ class MoleculeSet:
                 if molecule_database_src_type.lower() == "excel"
                 else pd.read_csv(molecule_database_src)
             )
-            # expects feature columns to be prefixed with feature_
-            # e.g. feature_smiles
-            feature_cols = [
+            # expects descriptor columns to be prefixed with descriptor_
+            # e.g. descriptor_smiles
+            descriptor_cols = [
                 column
                 for column in database_df.columns
-                if column.split("_")[0] == "feature"
+                if column.split("_")[0] == "descriptor"
             ]
-            database_feature_df = database_df[feature_cols]
+            database_descriptor_df = database_df[descriptor_cols]
             mol_names, mol_smiles, responses = None, None, None
-            if "feature_name" in feature_cols:
-                mol_names = database_feature_df["feature_name"].values.flatten(
+            if "descriptor_name" in descriptor_cols:
+                mol_names = database_descriptor_df["descriptor_name"].values.flatten(
                 )
-                database_feature_df = database_feature_df.drop(
-                    ["feature_name"], axis=1)
-            if "feature_smiles" in feature_cols:
-                mol_smiles = database_df["feature_smiles"].values.flatten()
-                database_feature_df = database_feature_df.drop(
-                    ["feature_smiles"], axis=1
+                database_descriptor_df = database_descriptor_df.drop(
+                    ["descriptor_name"], axis=1)
+            if "descriptor_smiles" in descriptor_cols:
+                mol_smiles = database_df["descriptor_smiles"].values.flatten()
+                database_descriptor_df = database_descriptor_df.drop(
+                    ["descriptor_smiles"], axis=1
                 )
 
             response_col = [
@@ -246,12 +250,12 @@ class MoleculeSet:
             if len(response_col) > 0:
                 # currently handles one response
                 responses = database_df[response_col].values.flatten()
-            for mol_id in database_feature_df.index:
+            for mol_id in database_descriptor_df.index:
                 if self.is_verbose:
                     print(
                         f"Processing "
                         f"({mol_id + 1}/"
-                        f"{len(database_feature_df.index)})"
+                        f"{len(database_descriptor_df.index)})"
                     )
                 mol_smile = mol_smiles[mol_id] if mol_smiles is not None \
                     else None
@@ -273,8 +277,8 @@ class MoleculeSet:
                         print(f"Molecule index {mol_id} could not be imported. "
                               f"Skipping")
 
-            if len(database_feature_df.columns) > 0:
-                features = database_feature_df.values
+            if len(database_descriptor_df.columns) > 0:
+                descriptors = database_descriptor_df.values
         else:
             raise FileNotFoundError(
                 f"{molecule_database_src} could not be found. "
@@ -283,7 +287,7 @@ class MoleculeSet:
             )
         if len(molecule_database) == 0:
             raise UserWarning("No molecular files found in the location!")
-        return molecule_database, features
+        return molecule_database, descriptors
 
     def _subsample_database(self, sampling_ratio, random_state):
         """Subsample a fixed proportion of the set.
@@ -396,6 +400,10 @@ class MoleculeSet:
                                 except NotInitializedError as e:
                                     e.message += "Similarity matrix could not be set "
                                     raise e
+                                except ValueError as e:
+                                    raise RuntimeError(
+                                        f'Unable to proccess molecule {molecule.mol_text}'
+                                    ) from e
                 queue.put(local_similarity_matrix)
                 return None
 
@@ -448,12 +456,17 @@ class MoleculeSet:
                             "Computing similarity of molecule num "
                             f"{target_mol_id + 1} against {source_mol_id + 1}"
                         )
-                    similarity_matrix[
-                        source_mol_id, target_mol_id
-                    ] = molecule.get_similarity_to(
-                        self.molecule_database[target_mol_id],
-                        similarity_measure=self.similarity_measure,
-                    )
+                    try:
+                        similarity_matrix[
+                            source_mol_id, target_mol_id
+                        ] = molecule.get_similarity_to(
+                            self.molecule_database[target_mol_id],
+                            similarity_measure=self.similarity_measure,
+                        )
+                    except ValueError as e:
+                        raise RuntimeError(
+                            f'Unable to proccess molecule {molecule.mol_text}'
+                        ) from e
 
         self.similarity_matrix = similarity_matrix
 
